#
# spec file for package python-watchdog
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%{?sle15_python_module_pythons}
Name:           python-watchdog
Version:        6.0.0
Release:        1.1
Summary:        Filesystem events monitoring
License:        Apache-2.0
URL:            https://github.com/gorakhargosh/watchdog
Source:         https://files.pythonhosted.org/packages/source/w/watchdog/watchdog-%{version}.tar.gz
BuildRequires:  %{python_module flaky}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Sphinx
Requires:       python-PyYAML >= 3.10
Requires:       python-pathtools >= 0.1.1
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pathtools >= 0.1.1}
BuildRequires:  %{python_module pytest-timeout}
BuildRequires:  %{python_module pytest}
# /SECTION test
%python_subpackages

%description
Python API and shell utilities to monitor file system events.

# doc only for Tumblweed because Leap rise up an systax error in version.py
%if 0%{?suse_version} > 1500
%package doc
Summary:        Documentation and examples for %{name}

%description doc
This package contains documentation and examples for %{name}.
%endif

%prep
%autosetup -p1 -n watchdog-%{version}
chmod -x README.rst
# Remove all shebangs
find src -name "*.py" | xargs sed -i -e '/^#!\//, 1d'

# Remove coverage testing
sed -i '/^[[:space:]]\+--cov/d' pyproject.toml

%build
%python_build
%if 0%{?suse_version} > 1500
cd docs && make html && rm -r build/html/.buildinfo build/html/objects.inv # Build HTML docs
%endif

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/watchmedo
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
sed -i '/--cov/d' setup.cfg
export LANG=en_US.UTF-8
# test_event_dispatcher randomly fails on SLE15
# test_unmount_watched_directory_filesystem requires sudo/root which is not available
# test_select_fd
%pytest -k 'not (test_event_dispatcher or test_unmount_watched_directory_filesystem or test_select_fd)'

%post
%python_install_alternative watchmedo

%postun
%python_uninstall_alternative watchmedo

%files %{python_files}
%license COPYING LICENSE
%doc AUTHORS changelog.rst MANIFEST.in README.rst
%python_alternative %{_bindir}/watchmedo
%{python_sitelib}/watchdog
%{python_sitelib}/watchdog-%{version}-py%{python_version}.egg-info

%if 0%{?suse_version} > 1500
%files %{python_files doc}
%doc docs/build/html
%endif

%changelog
* Tue Jan  7 2025 Adrian Schröter <adrian@suse.de>
- update to 6.0.0:
  - Breaking Changes
  - [inotify] Use of select.poll() instead of deprecated
    select.select(), if available.
  - [utils] Removed the unused echo_class() function from the
    echo module.
  - [utils] Removed the unused echo_instancemethod() function
    from the echo module.
  - [utils] Removed the unused echo_module() function from the
    echo module.
  - [utils] Removed the unused is_class_private_name() function
    from the echo module.
  - [utils] Removed the unused is_classmethod() function from
    the echo module.
  - [utils] Removed the unused is_method(met() function from
    the echo module.
  - [utils] Removed the unused method_name() function from the
    echo module.
  - [utils] Removed the unused name() function from the echo
    module.
  - [watchmedo] Removed the --trace CLI argument from the
    watchmedo log command, useless since events are logged by
    default at the LoggerTrick class level.
  - Other Changes Pin test dependecies.
  - [docs] Add typing info to quick start.
  - [inotify] Fix reading inotify file descriptor after closing
    it.
  - [utils] The stop_signal keyword-argument type of the
    AutoRestartTrick class can now be either a signal.Signals
    or an int.
  - [utils] Added the __repr__() method to the Trick class.
  - [watchmedo] Fixed Mypy issues.
  - [watchmedo] Added the __repr__() method to the
    HelpFormatter class.
  - [windows] Fixed Mypy issues.
- Switch off test coverage measurement.
- Skip test test_select_fd (gh#gorakhargosh/watchdog!1086 ?)
* Thu Jun 13 2024 Dirk Müller <dmueller@suse.com>
- update to 4.0.1:
  * [inotify] Fix missing event_filter for the full emitter
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 4.0.0:
  * Drop support for Python 3.7.
  * Add support for Python 3.12.
  * [snapshot] Add typing to dirsnapshot
  * [snapshot] Added DirectorySnapshotDiff.ContextManager
  * [events] FileSystemEvent, and subclasses, are now
    dataclass``es, and their ``repr() has changed
  * [windows] WinAPINativeEvent is now a dataclass, and its
    repr() has changed
  * [events] Log FileOpenedEvent, and FileClosedEvent, events in
    LoggingEventHandler
  * [tests] Improve FileSystemEvent coverage
  * [watchmedo] Log all events in LoggerTrick
  * [windows] The observers.read_directory_changes.WATCHDOG_TRAVE
    RSE_MOVED_DIR_DELAY hack was removed. The constant will be
    kept to prevent breaking other softwares.
  * Thanks to our beloved contributors: @BoboTiG, @msabramo
* Sun Jun 11 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
- Fix build error for Leap
  Generate doc only for Leap because it rise up an syntax error in
  version.py
* Mon Mar 20 2023 Dirk Müller <dmueller@suse.com>
- update to 3.0.0:
  * Drop support for Python 3.6.
  * ``watchdog`` is now PEP 561 compatible, and tested with
    ``mypy``
  * Fix missing ``>`` in ``FileSystemEvent.__repr__()``
  * [ci] Lots of improvements
  * [inotify] Return from ``InotifyEmitter.queue_events()`` if
    not launched when thread is inactive
  * [tests] Stability improvements
  * [utils] Remove handling of ``threading.Event.isSet`` spelling
  * [watchmedo] Fixed tricks YAML generation
* Tue Feb 28 2023 Dirk Müller <dmueller@suse.com>
- update to 2.3.1:
  * Run ``black`` on the entire source code
  * Bundle the ``requirements-tests.txt`` file in the source
    distribution
  * [watchmedo] Exclude ``FileOpenedEvent`` events from
    ``AutoRestartTrick``, and ``ShellCommandTrick``, to restore
    watchdog < 2.3.0 behavior. A better solution should be found
    in the future.
  * [watchmedo] Log ``FileOpenedEvent``, and ``FileClosedEvent``,
    events in ``LoggerTrick``
  * [inotify] Add support for ``IN_OPEN`` events: a
    ``FileOpenedEvent`` event will be fired
  * [watchmedo] Add optional event debouncing for ``auto-
    restart``, only restarting once if many events happen in
    quick succession (``--debounce-interval``)
  * [watchmedo] Exit gracefully on ``KeyboardInterrupt``
    exception (Ctrl+C)
  * [watchmedo] Add option to not auto-restart the command after
    it exits (``--no-restart-on-command-exit``)
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to v2.2.1:
  * [ci] Set the expected Python version when building release files
  * [ci] Update actions versions in use
  * [watchmedo] [regression] Fix usage of missing signal.SIGHUP attribute on
    non-Unix OSes (#935)
* Tue Dec 13 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2.2.0
  * 2022-12-05 • full history
    [build] Wheels are now available for Python 3.11 (#932)
    [documentation] HTML documentation builds are now tested for errors (#902)
    [documentation] Fix typos here, and there (#910)
    [fsevents2] The fsevents2 observer is now deprecated (#909)
    [tests] The error message returned by musl libc for error code -1 is now allowed (#923)
    [utils] Remove unnecessary code in dirsnapshot.py (#930)
    [watchmedo] Handle shutdown events from SIGHUP (#912)
    Thanks to our beloved contributors: @kurtmckee, @babymastodon, @QuantumEnergyE, @timgates42, @BoboTiG
* Sat Jul 23 2022 Dirk Müller <dmueller@suse.com>
- update to 2.1.9:
  * [fsevents] Fix flakey test to assert that there are no errors when stopping the emitter.
  * [inotify] Suppress occasional ``OSError: [Errno 9] Bad file descriptor`` at shutdown.
  * [watchmedo] Make ``auto-restart`` restart the sub-process if it terminates.
  * [watchmedo] Avoid zombie sub-processes when running ``shell-command`` without ``--wait``.
  * Fix adding failed emitters on observer schedule.
  * [inotify] Fix hang when unscheduling watch on a path in an unmounted filesystem.
  * [watchmedo] Fix broken parsing of ``--kill-after`` argument for the ``auto-restart`` command.
  * [watchmedo] Fix broken parsing of boolean arguments.
  * [watchmedo] Fix broken parsing of commands from ``auto-restart``, and ``shell-command``.
  * [watchmedo] Support setting verbosity level via ``-q/--quiet`` and ``-v/--verbose`` arguments.
  * Thanks to our beloved contributors: @taleinat, @kianmeng, @palfrey, @IlayRosenberg, @BoboTiG
  * Eliminate timeout in waiting on event queue.
  * [inotify] Fix ``not`` equality implementation for ``InotifyEvent``.
  * [watchmedo] Fix calling commands from within a Python script.
  * [watchmedo] ``PyYAML`` is loaded only when strictly necessary.
* Sun Oct 10 2021 Ben Greiner <code@bnavigator.de>
- Update to v2.1.6
  * [bsd] Fixed returned paths in kqueue.py and restored the
    overall results of the test suite. (#842)
  * [bsd] Updated FreeBSD CI support .(#841)
  * [watchmedo] Removed the argh dependency in favor of the builtin
    argparse module. (#836)
  * [watchmedo] Removed unexistant WindowsApiAsyncObserver
    references and --debug-force-winapi-async arguments.
  * [watchmedo] Improved the help output.
* Fri Sep 17 2021 Ben Greiner <code@bnavigator.de>
- Update to v2.1.5
  * Convert regexes of type str to list. (#831)
  * [watchmedo] Fix usage of os.setsid() and os.killpg() Unix-only
    functions. (#809)
  * Fix a possible AttributeError in SkipRepeatsQueue._put().
    (#818)
  * Allow overriding or adding custom event handlers to event
    dispatch map. (#814) -- reverted (#830)
  * Fix tests on big endian platforms. (#828)
* Mon Jul 12 2021 Antonio Larrosa <alarrosa@suse.com>
- Update to v2.1.3
  * Publish macOS ``arm64`` and ``universal2`` wheels.
* Tue Jun  1 2021 Antonio Larrosa <alarrosa@suse.com>
- Update to v2.1.2
  * [mac] Fix relative path handling for non-recursive watch
  * [windows] On PyPy, events happening right after start() were
    missed. Add a workaround for that
* Mon May 17 2021 Matej Cepl <mcepl@suse.com>
- Add missing BR on python-flaky.
* Mon May 17 2021 Antonio Larrosa <alarrosa@suse.com>
- Update to v2.1.1
  * [mac] Fix callback exceptions when the watcher is deleted but
    still receiving events
- Update to v2.1.0
  * [inotify] Simplify libc loading
  * [mac] Add support for non-recursive watches in FSEventsEmitter
  * [watchmedo] Add support for --debug-force-* arguments to tricks
- Update to v2.0.3
  * [mac] Use logger.debug() instead of logger.info()
  * Updated documentation links
- Update to v2.0.2
  * [mac] Add missing exception objects
- Update to v2.0.1
  * [mac] Fix a segmentation fault when dealing with unicode paths
  * Moved the CI from Travis-CI to GitHub Actions
- Update to v2.0.0
  * [mac] Drop support for macOS 10.12 and earlier
  * [mac] Support coalesced filesystem events
  * [mac] Fix an issue when renaming an item changes only the
    casing
  * [inotify] Add support for IN_CLOSE_WRITE events.
    A FileCloseEvent event will be fired. Note that
    IN_CLOSE_NOWRITE events are not handled to prevent much noise.
  * [inotify] Allow to stop the emitter multiple times
  * Avoid deprecated PyEval_InitThreads on Python 3.7+
* Wed Jan 13 2021 John Vandenberg <jayvdb@gmail.com>
- Run spec-cleaner
- Update to v1.0.2
  * [mac] Fix missing `event_id` attribute in `fsevents`
  * [mac] Add compatibility with old macOS versions
- from v1.0.1
  * Fix version with good metadatas.
- from v1.0.0
  * Versioning is now following https://semver.org/
  * Drop support for Python 2.7, 3.4 and 3.5
  * [mac] Regression fixes for native ``fsevents``
  * [windows] winapi.BUFFER_SIZE now defaults to 64000 instead of 2048
  * [windows] Introduced winapi.PATH_BUFFER_SIZE defaults to 2048
  * Use ``pathlib`` from the standard library, instead of pathtools
  * Allow file paths on Unix that don't follow the file system encoding
  * Removed long-time deprecated events.LoggingFileSystemEventHandler,
    use LoggingEventHandler instead
- from v0.10.4
  * Add ``logger`` parameter for the ``LoggingEventHandler``
  * Replace mutable default arguments with ``if None`` implementation
  * Expand tests to Python 2.7 and 3.5-3.10 for GNU/Linux, macOS
    and Windows
  * [mac] Performance improvements for the fsevents module
  * [mac] Prevent compilation of watchdog_fsevents.c on
    non-macOS machines
  * [watchmedo] Handle SIGTERM and SIGINT more reliably
* Wed Jul 22 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.10.3
  * Ensure ``ObservedWatch.path`` is a string
  * [inotify] Allow to monitor single file
  * [inotify] Prevent raising an exception when a file in a monitored folder has no permissions
* Wed Jun  3 2020 Tomáš Chvátal <tchvatal@suse.com>
- Skip randomly failing test test_event_dispatcher
* Mon May 18 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Tue Mar 10 2020 pgajdos@suse.com
- version update to 0.10.2
  - Fixed the ``build_ext`` command on macOS Catalina (`#628 <https://github.com/gorakhargosh/watchdog/pull/628>`__)
  - Fixed the installation of macOS requirements on non-macOS OSes (`#635 <https://github.com/gorakhargosh/watchdog/pull/635>`__)
  - Refactored ``dispatch()`` method of ``FileSystemEventHandler``,
    ``PatternMatchingEventHandler`` and ``RegexMatchingEventHandler``
  - [bsd] Improved tests support on non Windows/Linux platforms (`#633 <https://github.com/gorakhargosh/watchdog/pull/633>`__, `#639 <https://github.com/gorakhargosh/watchdog/pull/639>`__)
  - [bsd] Added FreeBSD CI support (`#532 <https://github.com/gorakhargosh/watchdog/pull/532>`__)
  - [bsd] Restored full support (`#638 <https://github.com/gorakhargosh/watchdog/pull/638>`__, `#641 <https://github.com/gorakhargosh/watchdog/pull/641>`__)
- deleted patches
  - add-missing-conftest.patch (upstreamed)
* Wed Nov  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Do not pull in Brownie as it is not needed
* Mon Nov 19 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.8.3
- Cherry-pick upstream patch to fix testsuite
  + add-missing-conftest.patch
- Update BuildRequires from setup.py
* Thu Aug  9 2018 tchvatal@suse.com
- Remove devel dependency
- Use %%license macro
* Sat Aug 12 2017 jengelh@inai.de
- Specify RPM group more exactly
* Sat Apr 22 2017 aloisio@gmx.com
- Converted to single-spec
- Split docs into separate package
* Fri Mar 11 2016 freitag@opensuse.org
- Update to version 0.8.3
  * Event emitters are no longer started on schedule if Observer is
    not already running.
  Changes from 0.8.0:
  * DirectorySnapshot: methods returning internal stat info replaced
    by mtime, inode and path methods.
  * DirectorySnapshot: walker_callback parameter deprecated.
  no more changelog available upstream
- Fix py compile mtime issue
- use record filelist feature of setup.py to gather proper filelist
* Mon Jan 14 2013 p.drouand@gmail.com
- Update to 0.6.0 version:
  * No changelog or NEWS file provided
* Tue Jan 31 2012 saschpe@suse.de
- Initial version
